@@ -1,4 +1,5 @@
 from django.forms import ImageField
+
 from ..specs import SpecHost
 from ..utils import generate
 
@@ -17,16 +18,16 @@ class ProcessedImageField(ImageField, SpecHost):
         SpecHost.__init__(self, processors=processors, format=format,
                           options=options, autoconvert=autoconvert, spec=spec,
                           spec_id=spec_id)
-        super(ProcessedImageField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def clean(self, data, initial=None):
-        data = super(ProcessedImageField, self).clean(data, initial)
+        data = super().clean(data, initial)
 
         if data and data != initial:
             spec = self.get_spec(source=data)
             f = generate(spec)
             # Name is required in Django 1.4. When we drop support for it
-            # then we can dirrectly return the result from `generate(spec)`
+            # then we can directly return the result from `generate(spec)`
             f.name = data.name
             return f
 
