@@ -1,5 +1,5 @@
-from .registry import register
 from .processors import Thumbnail as ThumbnailProcessor
+from .registry import register
 from .specs import ImageSpec
 
 
@@ -7,7 +7,7 @@ class Thumbnail(ImageSpec):
     def __init__(self, width=None, height=None, anchor=None, crop=None, upscale=None, **kwargs):
         self.processors = [ThumbnailProcessor(width, height, anchor=anchor,
                                               crop=crop, upscale=upscale)]
-        super(Thumbnail, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 register.generator('imagekit:thumbnail', Thumbnail)
