@@ -1,12 +1,7 @@
 from copy import copy
 from hashlib import md5
-from pickle import MARK, DICT
-try:
-    from pickle import _Pickler
-except ImportError:
-    # Python 2 compatible
-    from pickle import Pickler as _Pickler
-from .lib import StringIO
+from io import BytesIO
+from pickle import DICT, MARK, _Pickler
 
 
 class CanonicalizingPickler(_Pickler):
@@ -30,6 +25,6 @@ class CanonicalizingPickler(_Pickler):
 
 
 def pickle(obj):
-    file = StringIO()
+    file = BytesIO()
     CanonicalizingPickler(file, 0).dump(obj)
     return md5(file.getvalue()).hexdigest()
