@@ -1,7 +1,4 @@
-try:
-    from unittest.mock import Mock, PropertyMock, patch
-except:
-    from mock import Mock, PropertyMock, patch
+from unittest.mock import Mock, PropertyMock, patch
 
 from .models import Photo
 
